package com.muyu.source.domain;

import com.baomidou.mybatisplus.annotation.IdType;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableId;
import com.baomidou.mybatisplus.annotation.TableName;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.NoArgsConstructor;
import lombok.AllArgsConstructor;
import lombok.experimental.SuperBuilder;
import io.swagger.annotations.*;
import com.muyu.common.core.annotation.Excel;
import com.muyu.source.domain.req.SysDataSourceQueryReq;
import com.muyu.source.domain.req.SysDataSourceSaveReq;
import com.muyu.source.domain.req.SysDataSourceEditReq;
import com.muyu.common.core.web.domain.BaseEntity;

import java.util.Date;
import java.util.function.Supplier;

/**
 * 数据接入基本信息对象 sys_data_source
 *
 * @author wan
 * @date 2024-04-20
 */
@Data
@SuperBuilder
@NoArgsConstructor
@AllArgsConstructor
@TableName("sys_data_source")
@EqualsAndHashCode(callSuper = true)
@ApiModel(value = "SysDataSource", description = "数据接入基本信息")
public class SysDataSource extends BaseEntity {

    private static final long serialVersionUID = 1L;

    /** 数据源ID */
    @TableId(value = "id",type = IdType.AUTO)
    @ApiModelProperty(name = "数据源ID", value = "数据源ID")
    private Long id;

    /** 数据源名称 */
    @Excel(name = "数据源名称")
    @ApiModelProperty(name = "数据源名称", value = "数据源名称")
    private String sourceName;

    /** 数据来源系统名称 */
    @Excel(name = "数据来源系统名称")
    @ApiModelProperty(name = "数据来源系统名称", value = "数据来源系统名称", required = true)
    private String systemName;

    /** 主机地址 */
    @Excel(name = "主机地址")
    @ApiModelProperty(name = "主机地址", value = "主机地址")
    private String hostAddress;

    /** 主键端口号 */
    @Excel(name = "主键端口号")
    @ApiModelProperty(name = "主键端口号", value = "主键端口号")
    private Long hostNumber;

    /** 数据接入类型 */
    @Excel(name = "数据接入类型")
    @ApiModelProperty(name = "数据接入类型", value = "数据接入类型")
    private Long accessId;

    /** 数据连接参数 */
    @Excel(name = "数据连接参数")
    @ApiModelProperty(name = "数据连接参数", value = "数据连接参数")
    private String connectionParameters;

    /** 初始连接数量 */
    @Excel(name = "初始连接数量")
    @ApiModelProperty(name = "初始连接数量", value = "初始连接数量")
    private Long initialize;

    /** 最大连接数量 */
    @Excel(name = "最大连接数量")
    @ApiModelProperty(name = "最大连接数量", value = "最大连接数量")
    private Long maxInitialize;

    /** 最大等待时间
 */
    @Excel(name = "最大等待时间")
    @ApiModelProperty(name = "最大等待时间", value = "最大等待时间")
    private Long maxWaitingTime;

    /** 最大等待次数 */
    @Excel(name = "最大等待次数")
    @ApiModelProperty(name = "最大等待次数", value = "最大等待次数")
    private Long maxIsoFrequency;

    /** 数据库名称 */
    @Excel(name = "数据库名称")
    @ApiModelProperty(name = "数据库名称", value = "数据库名称")
    private String databaseName;

    @TableField(exist = false)
    private String accessName;
    /**
    * 查询构造器
    */
    public static SysDataSource queryBuild( SysDataSourceQueryReq sysDataSourceQueryReq){
        return SysDataSource.builder()
                .sourceName(sysDataSourceQueryReq.getSourceName())
                .systemName(sysDataSourceQueryReq.getSystemName())
                .databaseName(sysDataSourceQueryReq.getDatabaseName())
                .build();
    }

    /**
    * 添加构造器
    */
    public static SysDataSource saveBuild(SysDataSourceSaveReq sysDataSourceSaveReq, Supplier<String> createBy){
        return SysDataSource.builder()
                .sourceName(sysDataSourceSaveReq.getSourceName())
                .systemName(sysDataSourceSaveReq.getSystemName())
                .hostAddress(sysDataSourceSaveReq.getHostAddress())
                .hostNumber(sysDataSourceSaveReq.getHostNumber())
                .accessId(sysDataSourceSaveReq.getAccessId())
                .connectionParameters(sysDataSourceSaveReq.getConnectionParameters())
                .initialize(sysDataSourceSaveReq.getInitialize())
                .maxInitialize(sysDataSourceSaveReq.getMaxInitialize())
                .maxWaitingTime(sysDataSourceSaveReq.getMaxWaitingTime())
                .maxIsoFrequency(sysDataSourceSaveReq.getMaxIsoFrequency())
                .databaseName(sysDataSourceSaveReq.getDatabaseName())
                .remark(sysDataSourceSaveReq.getRemark())
                .createBy(createBy.get())
                .createTime(new Date())
                .build();
    }

    /**
    * 修改构造器
    */
    public static SysDataSource editBuild(Long id, SysDataSourceEditReq sysDataSourceEditReq){
        return SysDataSource.builder()
            .id(id)
                .sourceName(sysDataSourceEditReq.getSourceName())
                .systemName(sysDataSourceEditReq.getSystemName())
                .hostAddress(sysDataSourceEditReq.getHostAddress())
                .hostNumber(sysDataSourceEditReq.getHostNumber())
                .accessId(sysDataSourceEditReq.getAccessId())
                .connectionParameters(sysDataSourceEditReq.getConnectionParameters())
                .initialize(sysDataSourceEditReq.getInitialize())
                .maxInitialize(sysDataSourceEditReq.getMaxInitialize())
                .maxWaitingTime(sysDataSourceEditReq.getMaxWaitingTime())
                .maxIsoFrequency(sysDataSourceEditReq.getMaxIsoFrequency())
                .databaseName(sysDataSourceEditReq.getDatabaseName())
                .remark(sysDataSourceEditReq.getRemark())
                .build();
    }

}
