package com.muyu.source.controller;

import com.muyu.common.core.domain.Result;
import com.muyu.common.log.annotation.Log;
import com.muyu.common.log.enums.BusinessType;
import com.muyu.common.security.annotation.RequiresPermissions;
import com.muyu.source.domain.SysDataSource;
import com.muyu.source.service.AssetStructureService;
import com.muyu.source.service.SysAccessService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.apache.commons.math3.analysis.function.Add;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

/**
 * 资产Controller
 *
 * @ClassName AssetStructureController
 * @Author AnNan.Wang
 * @Date 2024/4/22 19:29
 */

@Api(tags = "资产")
@RestController
@RequestMapping("/structure")
public class AssetStructureController {
    @Autowired
    private AssetStructureService assetStructureService;

    /**
     * 同步资产结构
     * @param source
     * @return
     */
    @RequiresPermissions("source:structure:synchronization")
    @Log(title = "资产结构同步", businessType = BusinessType.DELETE)
    @ApiOperation("资产结构同步")
    @PostMapping("/{id}")
    public Result<String> synchronization(@PathVariable Long id){
        assetStructureService.synchronize(id);
        return Result.success();
    }
}
