package com.muyu.source.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.muyu.common.security.utils.SecurityUtils;
import com.muyu.source.domain.SysAccess;
import com.muyu.source.service.SysAccessService;
import io.swagger.annotations.*;
import org.apache.commons.lang3.SystemUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import com.muyu.common.core.domain.Result;
import com.muyu.common.core.utils.poi.ExcelUtil;
import com.muyu.common.core.web.controller.BaseController;
import com.muyu.common.log.annotation.Log;
import com.muyu.common.log.enums.BusinessType;
import com.muyu.common.security.annotation.RequiresPermissions;
import com.muyu.source.domain.SysDataSource;
import com.muyu.source.domain.req.SysDataSourceQueryReq;
import com.muyu.source.domain.req.SysDataSourceSaveReq;
import com.muyu.source.domain.req.SysDataSourceEditReq;
import com.muyu.source.service.SysDataSourceService;
import com.muyu.common.core.web.page.TableDataInfo;

/**
 * 数据接入基本信息Controller
 *
 * @author wan
 * @date 2024-04-20
 */
@Api(tags = "数据接入基本信息")
@RestController
@RequestMapping("/source")
public class SysDataSourceController extends BaseController {
    @Autowired
    private SysDataSourceService sysDataSourceService;
    @Autowired
    private SysAccessService sysAccessService;

    /**
     * 查询数据接入基本信息列表
     */
    @ApiOperation("获取数据接入基本信息列表")
    @RequiresPermissions("source:source:list")
    @GetMapping("/list")
    public Result<TableDataInfo<SysDataSource>> list(SysDataSourceQueryReq sysDataSourceQueryReq) {
        startPage();
        List<SysDataSource> list = sysDataSourceService.list(SysDataSource.queryBuild(sysDataSourceQueryReq));
        return getDataTable(list);
    }


    /**
     * 导出数据接入基本信息列表
     */
    @ApiOperation("导出数据接入基本信息列表")
    @RequiresPermissions("source:source:export")
    @Log(title = "数据接入基本信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, SysDataSource sysDataSource) {
        List<SysDataSource> list = sysDataSourceService.list(sysDataSource);
        ExcelUtil<SysDataSource> util = new ExcelUtil<SysDataSource>(SysDataSource.class);
        util.exportExcel(response, list, "数据接入基本信息数据");
    }

    /**
     * 获取数据接入基本信息详细信息
     */
    @ApiOperation("获取数据接入基本信息详细信息")
    @RequiresPermissions("source:source:query")
    @GetMapping(value = "/{id}")
    @ApiImplicitParam(name = "id", value = "id", required = true, dataType = "Long", paramType = "path", dataTypeClass = Long.class)
    public Result<SysDataSource> getInfo(@PathVariable("id") Long id) {
        return Result.success(sysDataSourceService.getById(id));
    }

    /**
     * 新增数据接入基本信息
     */
    @RequiresPermissions("source:source:add")
    @Log(title = "数据接入基本信息", businessType = BusinessType.INSERT)
    @PostMapping("/add")
    @ApiOperation("新增数据接入基本信息")
    public Result<String> add(@RequestBody SysDataSourceSaveReq sysDataSourceSaveReq) {
        return toAjax(sysDataSourceService.save(SysDataSource.saveBuild(sysDataSourceSaveReq, SecurityUtils::getUsername)));
    }

    /**
     * 修改数据接入基本信息
     */
    @RequiresPermissions("source:source:edit")
    @Log(title = "数据接入基本信息", businessType = BusinessType.UPDATE)
    @PutMapping("/{id}")
    @ApiOperation("修改数据接入基本信息")
    public Result<String> edit(@PathVariable Long id, @RequestBody SysDataSourceEditReq sysDataSourceEditReq) {
        return toAjax(sysDataSourceService.updateById(SysDataSource.editBuild(id,sysDataSourceEditReq)));
    }

    /**
     * 删除数据接入基本信息
     */
    @RequiresPermissions("source:source:remove")
    @Log(title = "数据接入基本信息", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    @ApiOperation("删除数据接入基本信息")
    @ApiImplicitParam(name = "id", value = "id", required = true, dataType = "Long", paramType = "path", dataTypeClass = String.class, example = "1,2,3,4")
    public Result<String> remove(@PathVariable List<Long> ids) {
        return toAjax(sysDataSourceService.removeBatchByIds(ids));
    }

    /**
     * 测试连接
     * @param id
     * @return
     */
    @RequiresPermissions("source:source:connect")
    @Log(title = "测试连接", businessType = BusinessType.DELETE)
    @PostMapping("/connect")
    @ApiOperation("删除数据接入基本信息")
    @ApiImplicitParam(name = "id", value = "id", required = true, dataType = "Long", paramType = "path", dataTypeClass = String.class, example = "1,2,3,4")
    public Result<String> connect(@RequestParam Long id) {
        return sysDataSourceService.connectList(id);
    }


}
