package com.muyu.source.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.muyu.common.core.domain.Result;
import com.muyu.source.domain.AssetStructure;
import com.muyu.source.domain.SysAccess;
import com.muyu.source.domain.SysDataSource;
import com.muyu.source.domain.red.UserPassword;
import com.muyu.source.mapper.AssetStructureMapper;
import com.muyu.source.mapper.SysAccessMapper;
import com.muyu.source.mapper.SysDataSourceMapper;
import com.muyu.source.service.AssetStructureService;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.sql.*;
import java.util.List;

/**
 * 资产service业务实现层
 *
 * @ClassName AssetStructureServiceImpl
 * @Author AnNan.Wang
 * @Date 2024/4/22 19:31
 */

@Slf4j
@Service
public class AssetStructureServiceImpl extends ServiceImpl<AssetStructureMapper,AssetStructure>
        implements AssetStructureService {
    @Autowired
    private AssetStructureMapper assetStructureMapper;
    @Autowired
    private SysDataSourceMapper sysDataSourceMapper;
    @Autowired
    private SysAccessMapper sysAccessMapper;


    @Override
    public void synchronize(Long id) {
        List<SysDataSource> sysDataSources = sysDataSourceMapper.selectList(
                new LambdaQueryWrapper<SysDataSource>() {{
                    eq(SysDataSource::getId, id);
                }}
        );
        for (SysDataSource sysDataSource : sysDataSources) {
            String url="jdbc:mysql://"+sysDataSource.getHostAddress()+":"+sysDataSource.getHostNumber()+"/"+sysDataSource.getDatabaseName();
            SysAccess sysAccess = sysAccessMapper.selectById(sysDataSource.getAccessId());

            UserPassword build = UserPassword.builder()
                    .USERNAME(sysAccess.getUser())
                    .PASSWORD(sysAccess.getPassword())
                    .build();
            try {
                Connection connection = DriverManager.getConnection(url, build.getUSERNAME(), build.getPASSWORD());
                if (connection!=null) {

                    String tableName="SELECT TABLE_NAME as 'name', TABLE_ROWS as 'dataTotal' FROM INFORMATION_SCHEMA.TABLES WHERE TABLE_SCHEMA = ?";

                    PreparedStatement preparedStatement2 = connection.prepareStatement(tableName);//
                    preparedStatement2.setString(1, sysDataSource.getDatabaseName());

                    ResultSet resultSet = preparedStatement2.executeQuery();

                    while (resultSet.next()) {
                        String name = resultSet.getString("name");
                        log.info("Name: " + name);
                        int dataTotal = resultSet.getInt("dataTotal");
                        log.info("dataTotal: " + dataTotal);
                        PreparedStatement preparedStatement = connection.prepareStatement("select * from " + name);
                        ResultSet executeQuery = preparedStatement.executeQuery();

                        ResultSetMetaData metaData3 = executeQuery.getMetaData();

                        //获取有几行
                        int columnCount = metaData3.getColumnCount();

                        for (int i = 1; i <= columnCount; i++) {
                            //表名
                            String catalogName = metaData3.getCatalogName(i);
                            //字段名称
                            String fileName = metaData3.getColumnName(i);
                            System.out.println(fileName);
                            //接入源名称
                            String sourceName = sysDataSource.getSourceName();
                            //数据来源系统名称
                            String systemName = sysDataSource.getSystemName();

                            assetStructureMapper.insert(
                                    AssetStructure.builder()
                                            .accessSourceName(sourceName)
                                            .fieldName(fileName)
                                            .dataSourceSystemName(systemName)
                                            .databaseName(catalogName)
                                            .databaseTableName(name)
                                            .dataVolume(columnCount)
                                            .dataQuantity(dataTotal)
                                            .build()
                            );
                        }
                    }
                }
            } catch (SQLException e) {
                e.printStackTrace();
            }
        }
    }

}
