package com.muyu.source.service.impl;

import java.sql.*;
import java.util.List;

import com.muyu.common.core.domain.Result;
import com.muyu.common.core.utils.ObjUtils;
import com.muyu.source.domain.SysAccess;
import com.muyu.source.mapper.SysAccessMapper;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.muyu.source.mapper.SysDataSourceMapper;
import com.muyu.source.domain.SysDataSource;
import com.muyu.source.service.SysDataSourceService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;

/**
 * 数据接入基本信息Service业务层处理
 *
 * @author wan
 * @date 2024-04-20
 */
@Slf4j
@Service
public class SysDataSourceServiceImpl extends ServiceImpl<SysDataSourceMapper, SysDataSource>  implements SysDataSourceService {

    @Autowired
    private SysDataSourceMapper sysDataSourceMapper;
    @Autowired
    private SysAccessMapper sysAccessMapper;
    /**
     * 查询数据接入基本信息列表
     *
     * @param sysDataSource 数据接入基本信息
     * @return 数据接入基本信息
     */
    @Override
    public List<SysDataSource> list(SysDataSource sysDataSource) {
        LambdaQueryWrapper<SysDataSource> queryWrapper = new LambdaQueryWrapper<>();
        if (ObjUtils.notNull(sysDataSource.getSourceName())){
            queryWrapper.like(SysDataSource::getSourceName, sysDataSource.getSourceName());
        }

        if (ObjUtils.notNull(sysDataSource.getSystemName())){
            queryWrapper.like(SysDataSource::getSystemName, sysDataSource.getSystemName());
        }
        if (ObjUtils.notNull(sysDataSource.getDatabaseName())){
            queryWrapper.like(SysDataSource::getDatabaseName, sysDataSource.getDatabaseName());
        }
        return list(queryWrapper);
    }


    @Override
    public Result<String> connectList(Long id) {
        List<SysDataSource> sysDataSources = sysDataSourceMapper.selectList(
                new LambdaQueryWrapper<SysDataSource>() {{
                    eq(SysDataSource::getId, id);
                }}
        );
        for (SysDataSource sysDataSource : sysDataSources) {
            String url="jdbc:mysql://"+sysDataSource.getHostAddress()+":"+sysDataSource.getHostNumber()+"/"+sysDataSource.getDatabaseName();
            if (sysDataSource.getAccessId()!=null && sysDataSource.getAccessId()==1) {
                //是否是mysql数据库
                SysAccess sysAccess = sysAccessMapper.selectById(sysDataSource.getAccessId());
                String USERNAME=sysAccess.getUser();
                String PASSWORD=sysAccess.getPassword();
                try {
                    Connection connection = DriverManager.getConnection(url, USERNAME, PASSWORD);
                    if (connection!=null) {
                        ResultSetMetaData metaData = information(connection);

                        int columnCount = metaData.getColumnCount();

                        for (int i = 1; i <= columnCount; i++) {
                            System.out.println("字段名称 : " + metaData.getColumnName(i));
                        }
                        return Result.success("连接成功");
                    }else {
                        return Result.error("连接失败");
                    }
                } catch (SQLException e) {
                    throw new RuntimeException(e);
                }

            }
            if (sysDataSource.getAccessId()!=null && sysDataSource.getAccessId()==2) {
                //是否是Oracle数据库
                SysAccess sysAccess = sysAccessMapper.selectById(sysDataSource.getAccessId());
                String USERNAME=sysAccess.getUser();
                String PASSWORD=sysAccess.getPassword();
                try {
                    Connection connection = DriverManager.getConnection(url, USERNAME, PASSWORD);
                    DatabaseMetaData metaData = connection.getMetaData();
                    System.out.println(metaData);
                    if (connection!=null) {
                        return Result.success("连接成功");
                    }else {
                        return Result.error("连接失败");
                    }
                } catch (SQLException e) {
                    return Result.error("连接失败");
                }
            }
        }
        return Result.error("连接失败");
    }

    public static  ResultSetMetaData information(Connection connection){
        try {
            PreparedStatement preparedStatement = connection.prepareStatement("select * from sys_data_source");
            ResultSet resultSet = preparedStatement.executeQuery();
            ResultSetMetaData metaData = resultSet.getMetaData();
            return metaData;
        } catch (SQLException e) {
            throw new RuntimeException(e);
        }
    }
}


